@@ -17,14 +17,23 @@ from typing import Callable, Any
 from typing import List, Dict, Any, Optional
 
 log=logging.getLogger(__name__)
+log.setLevel(logging.INFO)
+formatter = logging.Formatter(
+    fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S"
+)
+console_handler = logging.StreamHandler()
+console_handler.setFormatter(formatter)
+log.addHandler(console_handler)
+
 
 
 class ExecResult():
-    def __init__(self, exit_status_code, stdout="", stderr=""):
+    def __init__(self, ip,port,exit_status_code, stdout="", stderr=""):
         self.__exit_status_code = exit_status_code
         self.__stdout = stdout
         self.__stderr = stderr
-        log.info(f"ExecResults: exit_status_code: {exit_status_code},stdout: {stdout}, stderr: {stderr}")
+        log.info(f" {ip}:{port} | ExecResults: exit_status_code: {exit_status_code},stdout: {stdout}, stderr: {stderr}")
 
     @property
     def exit_status_code(self):
@@ -38,63 +47,14 @@ class ExecResult():
     def stderr(self):
         return self.__stderr
 
-def enter_and_leave_function(func: Callable) -> Callable:
-    """
-    函数调用日志装饰器：
-    1. 记录函数入参、调用位置
-    2. 正常执行时记录返回值
-    3. 异常时记录完整堆栈（含函数内具体报错行数）
-    """
-
-    @functools.wraps(func)  # 保留原函数元信息（如 __name__、__doc__）
-    def wrapper(*args: Any, **kwargs: Any) -> Any:
-        # 获取函数定义的文件路径和行号（基础位置信息）
-        func_def_file = inspect.getsourcefile(func) or "unknown_file"
-        func_def_file = func_def_file.split("/")[-1]
-        func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
-        log.info(
-            f"[{func_def_file}: {func_def_line}]"
-            f"[{func.__name__}()]"
-            f"| args={args}, kwargs={kwargs}"
-        )
-
-        try:
-            result = func(*args, **kwargs)
-            if isinstance(result, ExecResult):
-                if result.exit_status_code == 0:
-                    log.info(
-                        f"[{func_def_file}: {func_def_line}]"
-                        f" finish run function {func.__name__}(), stdout is: {result.stdout} "
-                    )
-                else:
-                    log.error(
-                        f"[{func_def_file}: {func_def_line}]"
-                        f" failed to run function {func.__name__}(), stderr is: {result.stderr} "
-                    )
-            else:
-                log.info(
-                    f"[{func_def_file}: {func_def_line}]"
-                    f" finish run function {func.__name__}(), return value is: {result} "
-                )
-            return result
-
-        except Exception as e:
-            error_traceback = traceback.format_exc()
-
-            log.error(
-                f"[{func_def_file}: {func_def_line}]"
-                f"failed to run function {func.__name__}() :Failed. "
-                f"| error_type：{type(e).__name__} "
-                f"| error_message：{str(e)} "
-                f"| full_stack_trace：\n{error_traceback}",
-                exc_info=False  # 已手动捕获堆栈，避免 logging 重复打印
-            )
-            raise  # 重新抛出异常，不中断原异常链路
-
-    return wrapper
+class _ThreadResult:
+    def __init__(self):
+        self.result = None
+        self.error = None
 
 class SSHClient(object):
     def __init__(self, ip="127.0.0.1", port=22, username="root", password="", connect_timeout=10,get_tty=False):
+        log.info(f"{self.__ip}:{self.__port} | init SSHClient, ip:{ip}, port:{port}, username:{username},password:{password},connect_timeout:{connect_timeout},get_tty:{get_tty}")
         self.__ip = ip
         self.__port = port
         self.__username = username
@@ -127,6 +87,7 @@ class SSHClient(object):
                 allow_agent=False,
                 timeout=self.__connect_timeout
             )
+            log.info(f"{self.__ip}:{self.__port} | create ssh session successfully.")
             return True
         except SSHException as e:
             log.warning(f"{self.__ip}:{self.__port} | cannot create ssh session, err msg is {str(e)}.")
@@ -140,18 +101,20 @@ class SSHClient(object):
             except Exception as e:
                 pass
 
-    @enter_and_leave_function
     def wait_for_sshable(self, timeout=60):
+        log.info(f"{self.__ip}:{self.__port} | wait for sshable, timeout is {timeout}")
         count=0
         while True:
             count += 1
+            log.info(f"{self.__ip}:{self.__port} | wait for sshable, count is {count}")
             if self.is_sshable:
+                log.info(f"{self.__ip}:{self.__port} | sshable")
                 return True
             if count > int(timeout/self.__connect_timeout):
+                log.warning(f"{self.__ip}:{self.__port} | wait for sshable timeout.")
                 return False
             time.sleep(self.__connect_timeout)
 
-    @enter_and_leave_function
     def __connect(self):
         try:
             self.__ssh = paramiko.SSHClient()
@@ -165,6 +128,7 @@ class SSHClient(object):
                 allow_agent=False,
                 timeout=self.__connect_timeout
             )
+            log.info(f"{self.__ip}:{self.__port} | create ssh session successfully.")
             return True
         except socket.timeout as e:
             log.warning(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
@@ -177,6 +141,7 @@ class SSHClient(object):
             return False
 
     def reconnect(self):
+        log.info(f"{self.__ip}:{self.__port} | reconnect")
         self.close()
         return self.__connect()
 
@@ -190,13 +155,13 @@ class SSHClient(object):
         except:
             pass
 
-    @enter_and_leave_function
     def _exec(self, cmd, promt_response,timeout=60):
+        log.info(f"{self.__ip}:{self.__port} | exec cmd:{cmd},promt_response: {promt_response},timeout:{timeout}")
         try:
             transport = self.__ssh.get_transport()
             if not transport or not transport.is_active():
                 log.warning(f"{self.__ip}:{self.__port} | ssh connection is not active.")
-                return ExecResult(1, "", "SSH连接已关闭或不可用")
+                return ExecResult(self.__ip,self.__port,1, "", "SSH连接已关闭或不可用")
 
             if promt_response:
                 channel = transport.open_session()
@@ -231,7 +196,8 @@ class SSHClient(object):
                     if channel.closed and not (channel.recv_ready() or channel.recv_stderr_ready()):
                         break
                 return_code = channel.recv_exit_status()
-                return ExecResult(return_code, output, stderr)
+                log.info(f"{self.__ip}:{self.__port} | exec cmd:{cmd},promt_response: {promt_response},timeout:{timeout},return_code:{return_code}")
+                return ExecResult(self.__ip,self.__port,return_code, output, stderr)
             else:
                 if self.__get_tty:
                     channel = transport.open_session()
@@ -252,31 +218,58 @@ class SSHClient(object):
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
-                return ExecResult(exit_status, std_output, std_err)
+                if exit_status == 0:
+                    log.info(f"{self.__ip}:{self.__port} | exec cmd:{cmd},promt_response: {promt_response},timeout:{timeout},return_code:{exit_status},stdout:{std_output}")
+                else:
+                    log.warning(f"{self.__ip}:{self.__port} | exec cmd:{cmd},promt_response: {promt_response},timeout:{timeout},return_code:{exit_status},stdout:{std_output},stderr:{std_err}")
+                return ExecResult(self.__ip,self.__port,exit_status, std_output, std_err)
         except Exception as e:
-            return ExecResult(1, "", str(e))
+            log.warning(f"{self.__ip}:{self.__port} | exceptions occurs,err msg is {str(e)}")
+            return ExecResult(self.__ip,self.__port,1, "", str(e))
 
-    @func_set_timeout(3600)
-    @enter_and_leave_function
     def exec(self, cmd, promt_response=[], timeout=60):
+        log.info(f"{self.__ip}:{self.__port} | exec cmd:{cmd},promt_response: {promt_response},timeout:{timeout}")
         try:
-            if not self.__ssh:
+            if not self.__ssh or not self.__ssh.is_active():
+                log.warning(f"{self.__ip}:{self.__port} | ssh transport is inactive, try reconnect...")
                 if not self.reconnect():
-                    raise RuntimeError("ssh transport is not active and failed to reconnect.")
-            return self._exec(cmd,promt_response,timeout)
+                    log.error(f"{self.__ip}:{self.__port} | ssh reconnect failed, transport is not active.")
+                    return ExecResult(self.__ip, self.__port, 1, "", "SSH连接已关闭或不可用，重连失败")
+
+            thread_result = _ThreadResult()
+
+            def _thread_func():
+                try:
+                    thread_result.result = self._exec(cmd, promt_response, timeout)
+                except Exception as inner_e:
+                    thread_result.error = inner_e
+
+            exec_thread = threading.Thread(target=_thread_func, daemon=True)
+            exec_thread.start()
+
+            exec_thread.join(timeout=timeout)
+
+            if exec_thread.is_alive():
+                log.error(f"{self.__ip}:{self.__port} | exec cmd timeout[{timeout}s], cmd: {cmd}")
+                return ExecResult(self.__ip, self.__port, 1, "", f"执行命令超时，超时时间{timeout}秒")
+            elif thread_result.error is not None:
+                err_msg = str(thread_result.error)
+                log.error(f"{self.__ip}:{self.__port} | exec cmd inner exceptions occurs, err msg: {err_msg}")
+                return ExecResult(self.__ip, self.__port, 1, "", err_msg)
+            else:
+                return thread_result.result
+
         except Exception as e:
-            log.warning(f"when run cmd: {cmd}, meets exception, err msg is {str(e)}")
-            return ExecResult(1, "", str(e))
+            err_msg = str(e)
+            log.error(f"{self.__ip}:{self.__port} | exec func exceptions occurs, err msg: {err_msg}")
+            return ExecResult(self.__ip, self.__port, 1, "", err_msg)
 
-    @enter_and_leave_function
     def _scp_to_remote(self, local_path, remote_path):
-        """拷贝本地文件/目录到远端：复用SSH认证，sftp递归拷贝（无额外依赖）"""
+        log.info(f"{self.__ip}:{self.__port} | 从本地拷贝文件到远端服务器: {local_path} -> {remote_path}")
         local_path = Path(local_path).resolve()
         remote_path = Path(remote_path)
 
-        # 定义sftp递归创建目录的辅助函数
         def sftp_mkdir_recursive(sftp, remote_dir):
-            """通过sftp递归创建远端目录"""
             dir_parts = str(remote_dir).split(os.sep)
             current_dir = ""
             for part in dir_parts:
@@ -285,49 +278,38 @@ class SSHClient(object):
                     continue
                 current_dir = os.path.join(current_dir, part)
                 try:
-                    # 尝试进入目录，若失败则创建
                     sftp.chdir(current_dir)
                 except OSError:
                     sftp.mkdir(current_dir)
                     sftp.chdir(current_dir)
 
-        # 定义sftp递归拷贝目录的辅助函数
         def sftp_copy_dir(sftp, local_dir, remote_dir):
-            """递归拷贝本地目录到远端（保留结构和权限）"""
-            # 确保远端目录存在
+            log.info(f" {self.__ip}:{self.__port} | 递归拷贝目录: {local_dir} -> {remote_dir}")
             sftp_mkdir_recursive(sftp, remote_dir)
-            # 遍历本地目录
             for entry in os.scandir(local_dir):
                 local_entry_path = Path(entry.path)
                 remote_entry_path = remote_dir / local_entry_path.name
-
                 if entry.is_file():
-                    # 拷贝文件
                     try:
                         sftp.put(str(local_entry_path), str(remote_entry_path))
-                        log.debug(f" {self.__ip}:{self.__port} | 已拷贝文件: {local_entry_path} -> {remote_entry_path}")
+                        log.info(f" {self.__ip}:{self.__port} | 已拷贝文件: {local_entry_path} -> {remote_entry_path}")
                     except Exception as e:
                         log.error(
                             f" {self.__ip}:{self.__port} | 文件拷贝失败: {local_entry_path} -> {remote_entry_path}, 错误: {str(e)}")
                         return False
                 elif entry.is_dir():
-                    # 递归拷贝子目录
                     if not sftp_copy_dir(sftp, local_entry_path, remote_entry_path):
                         return False
             return True
 
-        # 处理本地文件：直接sftp上传
         if local_path.is_file():
             remote_parent = remote_path.parent
-            # 创建文件父目录
             sftp_mkdir_recursive(self.__sftp, remote_parent)
-            # 上传文件
             try:
                 self.__sftp.put(str(local_path), str(remote_path))
             except Exception as e:
                 log.error(f" {self.__ip}:{self.__port} | 文件上传失败: {local_path} -> {remote_path}, 错误: {str(e)}")
                 return False
-            # 验证文件存在
             try:
                 self.__sftp.stat(str(remote_path))
             except OSError:
@@ -336,20 +318,15 @@ class SSHClient(object):
             log.info(f" {self.__ip}:{self.__port} | 文件拷贝完成: {local_path} -> {remote_path}")
             return True
 
-        # 处理本地目录：sftp递归拷贝（复用SSH认证，无需scp）
         if local_path.is_dir():
-            # 检查远端是否存在同名文件（冲突处理）
             try:
                 remote_stat = self.__sftp.stat(str(remote_path))
                 if not S_ISDIR(remote_stat.st_mode):
-                    # 远端是文件，删除后创建目录
                     log.warning(f" {self.__ip}:{self.__port} | 远端存在同名文件，删除后创建目录: {remote_path}")
                     self.__sftp.remove(str(remote_path))
             except OSError:
-                # 远端路径不存在，直接创建
                 pass
 
-            # 递归拷贝目录
             if sftp_copy_dir(self.__sftp, local_path, remote_path):
                 log.info(f" {self.__ip}:{self.__port} | 目录拷贝完成: {local_path} -> {remote_path}")
                 return True
@@ -357,83 +334,83 @@ class SSHClient(object):
                 log.error(f" {self.__ip}:{self.__port} | 目录拷贝失败: {local_path} -> {remote_path}")
                 return False
 
-        # 本地路径无效
         log.error(f" {self.__ip}:{self.__port} | 本地路径无效: {local_path}（不是文件或文件夹）")
         return False
 
-    @enter_and_leave_function
-    def scp_to_remote(self, local_path, remote_path, timeout=120):
+    def scp_to_remote(self, local_path, remote_path):
+        log.info(f" {self.__ip}:{self.__port} | SCP操作: 本地 {local_path} -> 远端 {remote_path}")
         try:
-            # 确保SSH和SFTP连接有效（复用已有认证信息）
             if not self.__ssh:
                 if not self.reconnect():
-                    raise RuntimeError("SSH连接未激活且重连失败")
+                    log.error(f"{self.__ip}:{self.__port} | SSH 通道未激活.")
+                    return False
             if not self.__sftp:
                 self.__sftp = self.__ssh.open_sftp()
 
             local_path = Path(local_path)
             remote_path = Path(remote_path)
-
             return self._scp_to_remote(local_path, remote_path)
         except Exception as e:
-            log.warning(f" {self.__ip}:{self.__port} | SCP操作异常: 本地 {local_path} -> 远端 {remote_path}",
-                        exc_info=True)
+            log.error(f" {self.__ip}:{self.__port} | SCP操作失败: {local_path} -> {remote_path}, 错误: {str(e)}")
             return False
 
-    @enter_and_leave_function
     def _scp_file_to_local(self, remote_path, local_path):
         if os.path.isfile(local_path):
+            log.info(f" {self.__ip}:{self.__port} | 删除本地文件: {local_path}")
             subprocess.run(['rm', '-rf', local_path], capture_output=True, text=True)
         for i in range(3):
             try:
                 self.__sftp.get(remote_path, local_path)
+                log.info(f" {self.__ip}:{self.__port} | 文件拷贝完成: {remote_path} -> {local_path}")
                 return True
             except OSError as e:
                 log.warning(
-                    f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error. err msg is {str(e)}")
+                    f" {self.__ip}:{self.__port} | 文件拷贝失败: {remote_path} -> {local_path}, 错误: {str(e)}")
                 self.reconnect()
                 self.__sftp = self.__ssh.open_sftp()
             except Exception as e:
                 log.warning(
-                    f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error.")
+                    f" {self.__ip}:{self.__port} | 文件拷贝失败: {remote_path} -> {local_path}, 错误: {str(e)}")
         else:
-            log.error(
-                f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error.")
+            log.error(f" {self.__ip}:{self.__port} | 文件拷贝失败: {remote_path} -> {local_path}")
             return False
 
 
-    @enter_and_leave_function
     def ssh_is_active(self):
         try:
             if self.__ssh:
                 return self.__ssh.get_transport().is_active()
             else:
+                log.info(f" {self.__ip}:{self.__port} | SSH连接未激活")
                 return False
         except Exception:
+            log.warning(f" {self.__ip}:{self.__port} | SSH连接异常")
             return False
 
-    @enter_and_leave_function
     def sftp_is_active(self):
         if not self.__ssh.get_transport() or not self.__ssh.get_transport().is_active():
+            log.warning(f" {self.__ip}:{self.__port} | SSH连接未激活")
             return False
         try:
             self.__sftp.getcwd()
+            log.info(f" {self.__ip}:{self.__port} | SFTP连接已激活")
             return True
         except (paramiko.SSHException, IOError, OSError,Exception) as e:
-            log.warning(f"SFTP不可用: {e}")
+            log.error(f" {self.__ip}:{self.__port} | SFTP连接异常: {str(e)}")
             return False
 
-    @enter_and_leave_function
-    def scp_file_to_local(self, remote_path, local_path,timeout=120):
+    def scp_file_to_local(self, remote_path, local_path):
+        log.info(f"{self.__ip}:{self.__port} | SCP文件开始: {remote_path} -> {local_path}")
         try:
             if not self.ssh_is_active():
                 if not self.reconnect():
-                    raise RuntimeError("ssh transport is not active and failed to reconnect.")
+                    log.error(f"{self.__ip}:{self.__port} | SSH连接未激活且重连失败")
+                    return False
             if not self.sftp_is_active():
                 self.__sftp = self.__ssh.open_sftp()
             return self._scp_file_to_local(remote_path, local_path)
         except Exception:
-            log.warning(f"when scp from remote {remote_path} to local {local_path}, meets exception.", exc_info=True)
+            log.error(f"{self.__ip}:{self.__port} | SCP文件 {remote_path} -> {local_path} 异常")
             return False
 
     def __del__(self):
